# pyannote.core

> advanced data structures for handling and visualizing temporal segments with attached labels.

## Installation

```bash
$ pip install pyannote.core
```

## Documentation

The documentation is available at [http://pyannote.github.io/pyannote-core](http://pyannote.github.io/pyannote-core).

Sample notebooks are available [here](https://nbviewer.jupyter.org/github/pyannote/pyannote-core/blob/develop/notebook/index.ipynb).

## Citation

If you use `pyannote.core` in your research, please use the following citation:

```bibtex
@inproceedings{pyannote.metrics,
 author = {Herv\'e Bredin},
 title = {{pyannote.metrics: a toolkit for reproducible evaluation, diagnostic, and error analysis of speaker diarization systems}},
 booktitle = {{Interspeech 2017, 18th Annual Conference of the International Speech Communication Association}},
 year = {2017},
 month = {August},
 address = {Stockholm, Sweden},
 url = {http://pyannote.github.io/pyannote-metrics},
}
```
